@@ -14,10 +14,10 @@ def istimezone(val: str) -> bool:
     """
     # val = val.replace(':', '').strip()
     status = val in [
-        '-1200', '-1100', '-1000', '-0930', '-0900', '-0800', '-0700', '-0600', '-0500', '-0400',
-        '-0330', '-0300', '-0200', '-0100', '+0000', '+0100', '+0200', '+0300', '+0330', '+0400',
+        '−1200', '−1100', '−1000', '−0930', '−0900', '−0800', '−0700', '−0600', '−0500', '−0400',
+        '−0330', '−0300', '−0200', '−0100', '+0000', '+0100', '+0200', '+0300', '+0330', '+0400',
         '+0430', '+0500', '+0530', '+0545', '+0600', '+0630', '+0700', '+0800', '+0845', '+0900',
-        '+0930', '+1000', '+1030', '+1100', '+1200', '+1245', '+1300', '+1400'
+        '+0930', '+1000', '+1030', '+1100', '+1200', '+1245', '+1300', '+1400',
     ]
     return status
 
